package main

import (
	"fmt"
	"os"
	"os/user"
	"path"
	"strings"
	"syscall"
)

const (
	PATH_TO_USER_CONFIG_FULL = "/etc/hestia_php_selector/%s/php.path"
	PATH_TO_LOCAL_PHP        = "php_sel/php.path"
)

func isExecOther(mode os.FileMode) bool {
	return mode&0001 != 0
}

func getPHPVerFromConf(path1 string) (string, error) {
	_, err := os.Stat(path1)
	if err != nil {
		sys_path := fmt.Sprintf(PATH_TO_USER_CONFIG_FULL, "system")
		if path1 == sys_path {
			return "", fmt.Errorf("user config reading error %s", err)
		} else {
			return getPHPVerFromConf(sys_path)
		}
	}
	content, err := os.ReadFile(path1)
	if err != nil {
		return "", fmt.Errorf("user config reading error %s", err)
	}
	result := strings.Split(strings.Trim(string(content), "\n "), "\n")[0]
	return result, nil

}

func getUserPHPVer() (string, error) {
	user, err := user.Current()
	if err != nil {
		return "", fmt.Errorf("user information error %s", err)
	}
	username := user.Username
	if username == "root" {
		username = "system"
	}
	var pathToConf string
	if username == "system" {
		pathToConf = fmt.Sprintf(PATH_TO_USER_CONFIG_FULL, username)
	} else {
		pathToConf = path.Join(user.HomeDir, PATH_TO_LOCAL_PHP)
	}
	phpVer, err := getPHPVerFromConf(pathToConf)
	if err != nil {
		return "", err
	}
	if finfo, err := os.Stat(phpVer); err != nil {
		return "", err
	} else {
		fmode := finfo.Mode()
		if !isExecOther(fmode) {
			return "", fmt.Errorf("not executable by others %s", phpVer)
		}
		if strings.Contains(finfo.Name(), "hestiacp-php-selector") {
			return "", fmt.Errorf("infinite symbolic link")
		}
	}
	return phpVer, nil
}

func inner_main() int {
	phpPath, err := getUserPHPVer()
	if err != nil {
		fmt.Fprintln(os.Stderr, err)
		return 1
	}
	if phpPath == "" {
		fmt.Fprintln(os.Stderr, "no php supported")
		return 1
	}
	err = syscall.Exec(phpPath, os.Args, os.Environ())
	if err != nil {
		fmt.Fprintln(os.Stderr, err)
	}
	return 1
}

func main() {
	os.Exit(inner_main())
}
